@@ -7,7 +7,8 @@ from python_framework.api.src.enumeration.HttpStatus import HttpStatus
 
 @Function
 def EncapsulateItWithGlobalException(message=DEFAULT_MESSAGE, status=HttpStatus.INTERNAL_SERVER_ERROR) :
-    def Function(function,*args,**kwargs) :
+    def Wrapper(function,*args,**kwargs) :
+        log.debug(Wrapper, f'Wrapping {function} function with (*{args} args and **{kwargs} kwargs)')
         def wrapedFunction(*args,**kwargs) :
             try :
                 functionReturn = function(*args,**kwargs)
@@ -21,4 +22,4 @@ def EncapsulateItWithGlobalException(message=DEFAULT_MESSAGE, status=HttpStatus.
             return functionReturn
         ReflectionHelper.overrideSignatures(wrapedFunction, function)
         return wrapedFunction
-    return Function
+    return Wrapper
